aboutsummaryrefslogtreecommitdiffstats
path: root/packet-llc.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2003-09-03 06:27:03 +0000
committerGuy Harris <guy@alum.mit.edu>2003-09-03 06:27:03 +0000
commit172159397390fbb6467b41d32aed46da7d7b4288 (patch)
tree1e1adaa5cd9633b607ae536e1a5529c9bb0786aa /packet-llc.h
parente076cb925f3d61ab5ab72580b8a36f153ce2e9d5 (diff)
Fix up the API for adding support for new OUI's to the LLC dissector.
Use that API to create the table for the Cisco OUI 00:00:0C. svn path=/trunk/; revision=8351
Diffstat (limited to 'packet-llc.h')
-rw-r--r--packet-llc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/packet-llc.h b/packet-llc.h
index 7cad2b5786..948d6ad092 100644
--- a/packet-llc.h
+++ b/packet-llc.h
@@ -1,6 +1,6 @@
/* packet-llc.h
*
- * $Id: packet-llc.h,v 1.10 2003/08/28 01:29:16 guy Exp $
+ * $Id: packet-llc.h,v 1.11 2003/09/03 06:27:03 guy Exp $
*
* Ethereal - Network traffic analyzer
* By Gerald Combs <gerald@ethereal.com>
@@ -30,9 +30,9 @@ void dissect_snap(tvbuff_t *, int, packet_info *, proto_tree *,
proto_tree *, int, int, int, int, int);
/*
* Add an entry for a new OID.
*/
-void llc_add_oid(guint32, const char *, char *, int);
+void llc_add_oui(guint32, const char *, char *, hf_register_info *);
extern const value_string sap_vals[];
@@ -30,9 +30,9 @@ void dissect_snap(tvbuff_t *, int, packet_info *, proto_tree *,
proto_tree *, int, int, int, int, int);
/*
- * Add an entry for a new OID.
+ * Add an entry for a new OUI.
*/